# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class Output(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entangled_at_time': 'float',
        'entangled_memory_entangled_at_time': 'float',
        'entangled_memory_index': 'float',
        'entangled_with_node': 'str',
        'fidelity': 'float'
    }

    attribute_map = {
        'entangled_at_time': 'entangledAtTime',
        'entangled_memory_entangled_at_time': 'entangledMemoryEntangledAtTime',
        'entangled_memory_index': 'entangledMemoryIndex',
        'entangled_with_node': 'entangledWithNode',
        'fidelity': 'fidelity'
    }

    def __init__(self, entangled_at_time=None, entangled_memory_entangled_at_time=None, entangled_memory_index=None, entangled_with_node=None, fidelity=None, local_vars_configuration=None):  # noqa: E501
        """Output - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._entangled_at_time = None
        self._entangled_memory_entangled_at_time = None
        self._entangled_memory_index = None
        self._entangled_with_node = None
        self._fidelity = None
        self.discriminator = None

        if entangled_at_time is not None:
            self.entangled_at_time = entangled_at_time
        if entangled_memory_entangled_at_time is not None:
            self.entangled_memory_entangled_at_time = entangled_memory_entangled_at_time
        if entangled_memory_index is not None:
            self.entangled_memory_index = entangled_memory_index
        if entangled_with_node is not None:
            self.entangled_with_node = entangled_with_node
        self.fidelity = fidelity

    @property
    def entangled_at_time(self):
        """Gets the entangled_at_time of this Output.  # noqa: E501

        Time at which it was entangled at, relative to beginning of timeline  # noqa: E501

        :return: The entangled_at_time of this Output.  # noqa: E501
        :rtype: float
        """
        return self._entangled_at_time

    @entangled_at_time.setter
    def entangled_at_time(self, entangled_at_time):
        """Sets the entangled_at_time of this Output.

        Time at which it was entangled at, relative to beginning of timeline  # noqa: E501

        :param entangled_at_time: The entangled_at_time of this Output.  # noqa: E501
        :type: float
        """

        self._entangled_at_time = entangled_at_time

    @property
    def entangled_memory_entangled_at_time(self):
        """Gets the entangled_memory_entangled_at_time of this Output.  # noqa: E501

        Time at which it was this memory's entangled memory was entangled at, relative to beginning of timeline  # noqa: E501

        :return: The entangled_memory_entangled_at_time of this Output.  # noqa: E501
        :rtype: float
        """
        return self._entangled_memory_entangled_at_time

    @entangled_memory_entangled_at_time.setter
    def entangled_memory_entangled_at_time(self, entangled_memory_entangled_at_time):
        """Sets the entangled_memory_entangled_at_time of this Output.

        Time at which it was this memory's entangled memory was entangled at, relative to beginning of timeline  # noqa: E501

        :param entangled_memory_entangled_at_time: The entangled_memory_entangled_at_time of this Output.  # noqa: E501
        :type: float
        """

        self._entangled_memory_entangled_at_time = entangled_memory_entangled_at_time

    @property
    def entangled_memory_index(self):
        """Gets the entangled_memory_index of this Output.  # noqa: E501

        The index of the memory this memory is entangled with in entangledWithNode  # noqa: E501

        :return: The entangled_memory_index of this Output.  # noqa: E501
        :rtype: float
        """
        return self._entangled_memory_index

    @entangled_memory_index.setter
    def entangled_memory_index(self, entangled_memory_index):
        """Sets the entangled_memory_index of this Output.

        The index of the memory this memory is entangled with in entangledWithNode  # noqa: E501

        :param entangled_memory_index: The entangled_memory_index of this Output.  # noqa: E501
        :type: float
        """

        self._entangled_memory_index = entangled_memory_index

    @property
    def entangled_with_node(self):
        """Gets the entangled_with_node of this Output.  # noqa: E501

        The node name with which this memory is entangled  # noqa: E501

        :return: The entangled_with_node of this Output.  # noqa: E501
        :rtype: str
        """
        return self._entangled_with_node

    @entangled_with_node.setter
    def entangled_with_node(self, entangled_with_node):
        """Sets the entangled_with_node of this Output.

        The node name with which this memory is entangled  # noqa: E501

        :param entangled_with_node: The entangled_with_node of this Output.  # noqa: E501
        :type: str
        """

        self._entangled_with_node = entangled_with_node

    @property
    def fidelity(self):
        """Gets the fidelity of this Output.  # noqa: E501

        The fidelity of the memory at the current moment in simulation  # noqa: E501

        :return: The fidelity of this Output.  # noqa: E501
        :rtype: float
        """
        return self._fidelity

    @fidelity.setter
    def fidelity(self, fidelity):
        """Sets the fidelity of this Output.

        The fidelity of the memory at the current moment in simulation  # noqa: E501

        :param fidelity: The fidelity of this Output.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and fidelity is None:  # noqa: E501
            raise ValueError("Invalid value for `fidelity`, must not be `None`")  # noqa: E501

        self._fidelity = fidelity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Output):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Output):
            return True

        return self.to_dict() != other.to_dict()
