# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.output import Output  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestOutput(unittest.TestCase):
    """Output unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Output
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.output.Output()  # noqa: E501
        if include_optional :
            return Output(
                entangled_at_time = 1.337, 
                entangled_memory_entangled_at_time = 1.337, 
                entangled_memory_index = 1.337, 
                entangled_with_node = '0', 
                fidelity = 1.337
            )
        else :
            return Output(
                fidelity = 1.337,
        )

    def testOutput(self):
        """Test Output"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
