# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum_networking
from aliro_quantum_networking.api.submissions_api import SubmissionsApi  # noqa: E501
from aliro_quantum_networking.rest import ApiException


class TestSubmissionsApi(unittest.TestCase):
    """SubmissionsApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum_networking.api.submissions_api.SubmissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_submissions_delete(self):
        """Test case for submissions_delete

        delete submissions  # noqa: E501
        """
        pass

    def test_submissions_details_stream_get(self):
        """Test case for submissions_details_stream_get

        get details about a submission's results  # noqa: E501
        """
        pass

    def test_submissions_overview_stream_get(self):
        """Test case for submissions_overview_stream_get

        get a list of user's submissions  # noqa: E501
        """
        pass

    def test_submissions_post(self):
        """Test case for submissions_post

        submit a new submission  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
