# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.submission_aqn_output_all_of import SubmissionAqnOutputAllOf  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestSubmissionAqnOutputAllOf(unittest.TestCase):
    """SubmissionAqnOutputAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SubmissionAqnOutputAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.submission_aqn_output_all_of.SubmissionAqnOutputAllOf()  # noqa: E501
        if include_optional :
            return SubmissionAqnOutputAllOf(
                run_results = [
                    aliro_quantum_networking.models.submission_aqn_output_all_of_run_results.SubmissionAqnOutput_allOf_runResults(
                        nodes = {
                            'key' : aliro_quantum_networking.models.submission_aqn_output_all_of_nodes.SubmissionAqnOutput_allOf_nodes(
                                memories = [
                                    null
                                    ], )
                            }, 
                        status = aliro_quantum_networking.models.status.Status(
                            status_title = 'COMPLETED', 
                            status_message = '0', ), )
                    ], 
                submission_overview = null
            )
        else :
            return SubmissionAqnOutputAllOf(
                run_results = [
                    aliro_quantum_networking.models.submission_aqn_output_all_of_run_results.SubmissionAqnOutput_allOf_runResults(
                        nodes = {
                            'key' : aliro_quantum_networking.models.submission_aqn_output_all_of_nodes.SubmissionAqnOutput_allOf_nodes(
                                memories = [
                                    null
                                    ], )
                            }, 
                        status = aliro_quantum_networking.models.status.Status(
                            status_title = 'COMPLETED', 
                            status_message = '0', ), )
                    ],
                submission_overview = null,
        )

    def testSubmissionAqnOutputAllOf(self):
        """Test SubmissionAqnOutputAllOf"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
