# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.submission_overview_output import SubmissionOverviewOutput  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestSubmissionOverviewOutput(unittest.TestCase):
    """SubmissionOverviewOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SubmissionOverviewOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.submission_overview_output.SubmissionOverviewOutput()  # noqa: E501
        if include_optional :
            return SubmissionOverviewOutput(
                name = '0', 
                runs = 1, 
                timeout = 1, 
                timeline_stop_time = 0, 
                complete_date = '0', 
                create_date = '0', 
                id = '0', 
                status = 'COMPLETED', 
                submission_overview_type = '0', 
                summary = aliro_quantum_networking.models.statistics_summary.StatisticsSummary(
                    average_entanglement_fidelity = 1.337, 
                    average_entanglement_rate = 1.337, 
                    average_pairs_entangled = 1.337, )
            )
        else :
            return SubmissionOverviewOutput(
                name = '0',
                create_date = '0',
                id = '0',
                status = 'COMPLETED',
                submission_overview_type = '0',
                summary = aliro_quantum_networking.models.statistics_summary.StatisticsSummary(
                    average_entanglement_fidelity = 1.337, 
                    average_entanglement_rate = 1.337, 
                    average_pairs_entangled = 1.337, ),
        )

    def testSubmissionOverviewOutput(self):
        """Test SubmissionOverviewOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
