# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum_networking
from aliro_quantum_networking.api.utils_api import UtilsApi  # noqa: E501
from aliro_quantum_networking.rest import ApiException


class TestUtilsApi(unittest.TestCase):
    """UtilsApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum_networking.api.utils_api.UtilsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_utils_support_post(self):
        """Test case for utils_support_post

        Send a support email to Aliro staff  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
