# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.email_info import EmailInfo  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestEmailInfo(unittest.TestCase):
    """EmailInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EmailInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.email_info.EmailInfo()  # noqa: E501
        if include_optional :
            return EmailInfo(
                content_text = '0', 
                subject = '0'
            )
        else :
            return EmailInfo(
        )

    def testEmailInfo(self):
        """Test EmailInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
